<template>
  <el-dialog
    title="模型列表"
    :visible.sync="dialogVisible"
    @close="cancel"
    width="70%">
    <el-row :gutter="20">
       <el-col :span="showMap ? 12 : 24" :xs="24">
        <AppTable ref="AppTable"  :showDeptSearch="false" :url="'tower/model/list'" :tableColumns="tableColumns"  :showSearchBtn="false">
          <template #operator="{ row }">
            <el-button size="mini" type="text"
              @click="clickRow(row)">预览</el-button>
            <el-button size="mini" type="text"
              @click="chooseRow(row)">选择</el-button>
          </template>
          <template #modelType="{ row }">
            <DictTag :options="dict.type.model_type" :value="row.modelType"></DictTag>
          </template>
        </AppTable>
      </el-col>
       <el-col :span="12" :xs="24" v-if="showMap">
          <CesiumMap ></CesiumMap>
       </el-col>
     </el-row>
    <span slot="footer" class="dialog-footer">
      <el-button @click="cancel">取 消</el-button>
      <el-button type="primary" @click="dialogVisible = false">确 定</el-button>
    </span>
  </el-dialog>
</template>
<script>
import CesiumMap from "../../../../utils/components/cesium-map.vue";
  export default {
    name:'chooseModelDialog',
    dicts: ['model_type'],
    components: {
      CesiumMap
    },
    data() {
      return {
        dialogVisible: true,
        showMap:false,
        tableColumns: [
            {
              label: '模型名称',
              prop: 'modelName'
            },
             {
              label: '模型类型',
              type: 'slot',
              slotName: 'modelType'
            },
            {
              label: '模型路径',
              prop: 'modelRoute'
            },
            {
              label: '操作',
              type: 'slot',
              slotName: 'operator',
              width: '330px'
            },
        ],
      };
    },
    methods: {
      cancel(){
        this.showMap = false
        this.$emit('cancel')
      },
      chooseRow(row){
        this.showMap = false
        this.$emit('cancel')
        this.$emit('getRowData',row)
      },  
      clickRow(row){
        console.log(row)
        this.showMap =true
        setTimeout(()=>{
          const position = Cesium.Cartesian3.fromDegrees(0, 0, 0);
          // 设置模型方向（可选）
          // const heading = Cesium.Math.toRadians(135); // 朝东南方向
          let model = viewer.entities.getById("modelList");
          const heading = Cesium.Math.toRadians(120); // 朝东南方向
          const pitch = 0;
          const roll = 0;
          const orientation = Cesium.Transforms.headingPitchRollQuaternion(
            position,
            new Cesium.HeadingPitchRoll(heading, pitch, roll)
          );
          if(!model) {
            // 加载 glTF 模型
            const entity = viewer.entities.add({
              id: "modelList",
              name: "modelList",
              position: position,
              orientation: orientation,
              model: {
                uri: row.modelRoute, // 替换成你的模型路径
              },
            });
            viewer.flyTo(entity)
          }else {
            model.orientation = orientation
          }
        },1000)
      },
    }
  };
</script>